[![Build Status](https://api.travis-ci.org/uw-it-aca/uw-restclients-libraries.svg?branch=master)](https://travis-ci.org/uw-it-aca/uw-restclients-libraries)
[![Coverage Status](https://coveralls.io/repos/uw-it-aca/uw-restclients-libraries/badge.png?branch=master)](https://coveralls.io/r/uw-it-aca/uw-restclients-libraries?branch=master)

# uw-restclients-libraries
REST client for the UW Libraries web services
